********************************************
**SOCIAL RETURNS TO EXPERIMENT - 2009 CCES**
********************************************
use RawData/cces09_yale_output.dta, clear

*** DEMOGRAPHICS
gen weight=v200
gen race=v211
tab race, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_other "Other Race/Multiple/Refused = 1"
label var r_white "White = 1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"
gen age=v288
label var age "Age (in years)"
recode v208 (1=0) (2=1) (*=.), gen(female)
label var female "Female=1"
recode cc424 (1=-3) (2=-2) (3=-1) (4 8=0) (5=1) (6=2) (7=3) (*=.), gen(pid)
recode pid (-3/-1=-1) (1/3=1) (0=0) (*=.), gen(pid3)
label var pid "Party ID (-3=S. Dem; 3=S. Rep)"
recode v244 (1=4) (2=3) (3=2) (4=1) (*=.), gen(interest)
label var interest "Political Interest (1-4)"
recode v213 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (*=.), gen(educ)
label var educ "Education (1=No HS; 6=post-grad)"
recode v246 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (8=8) (9=9) (10=10) (11=11) (12=12) (13=13) (14=14) (15=15) (*=.), gen(income)
label var income "Income (1-14; 15=Refused)"
gen incomemis=(income==15)
label var incomemis "Income Missing"

* On Form C
keep if yal_form==3

******* OUTCOMES *******
foreach i in 22 23 24 25 97 98 99 100{
if `i'==22 | `i'==97 {
local c=1
}
else{
local c=`c'+1
}
if `i'<30{
gen sr_vign_`c'_impress=yala`i'b
gen sr_vign_`c'_responsible=yala`i'd
gen sr_vign_`c'_respect=yala`i'e
}
else{
gen sr_single_`c'_impress=yala`i'b
gen sr_single_`c'_responsible=yala`i'd
gen sr_single_`c'_respect=yala`i'e
}
}

recode sr_vign* sr_single* (1=3) (2=2) (3=1) (4=0) (5=-1) (6=-2) (7=-3) (*=.)
forvalues i=1/4{
gen sr_vign_`i'_summary=(sr_vign_`i'_impress+sr_vign_`i'_responsible+sr_vign_`i'_respect)/3
gen sr_single_`i'_summary=(sr_single_`i'_impress+sr_single_`i'_responsible+sr_single_`i'_respect)/3

label var sr_vign_`i'_impress "Vignette `i': Postive Impression (-3=St. Disagree;3=St. Agree)"
label var sr_vign_`i'_responsible "Vignette `i': Is Responsible (-3=St. Disagree;3=St. Agree)"
label var sr_vign_`i'_respect "Vignette `i': I Respect (-3=St. Disagree;3=St. Agree)"
label var sr_vign_`i'_summary "Vignette `i': I Respect (-3=St. Disagree;3=St. Agree)"
label var sr_single_`i'_impress "Single Phrase `i': Postive Impression (-3=St. Disagree;3=St. Agree)"
label var sr_single_`i'_responsible "Single Phrase `i': Is Responsible (-3=St. Disagree;3=St. Agree)"
label var sr_single_`i'_respect "Single Phrase `i': I Respect (-3=St. Disagree;3=St. Agree)"
}

** VIGNETTE TREATMENTS ** 
tab educ22, gen(sr_vign_1_t_educ)
drop sr_vign_1_t_educ2
rename sr_vign_1_t_educ1 sr_vign_1_t_educ
label var sr_vign_1_t_educ "Education (1=College degree; 0=HS diploma)"

tab tax22, gen(sr_vign_1_t_tax)
drop sr_vign_1_t_tax1
rename sr_vign_1_t_tax2 sr_vign_1_t_tax
label var sr_vign_1_t_tax "Pays Taxes (1=On time; 0=Late)"

tab current23, gen(sr_vign_2_t_current)
drop sr_vign_2_t_current1
rename sr_vign_2_t_current2 sr_vign_2_t_current
label var sr_vign_2_t_current "Current Events (1=Stays informed; 0=Does not stay informed)"

tab litter23, gen(sr_vign_2_t_recycle)
drop sr_vign_2_t_recycle1
rename sr_vign_2_t_recycle2 sr_vign_2_t_recycle
label var sr_vign_2_t_recycle "Recycles (1=yes; 0=no)"

forvalues i=22/23{
local a=`i'-21

tab vote`i', mis gen(sr_vign_`a'_t_vote)
drop sr_vign_`a'_t_vote1 
rename sr_vign_`a'_t_vote2 sr_vign_`a'_t_always
rename sr_vign_`a'_t_vote3 sr_vign_`a'_t_never
rename sr_vign_`a'_t_vote4 sr_vign_`a'_t_usually 
label var sr_vign_`a'_t_always "Vote (1=Always)"
label var sr_vign_`a'_t_never "Vote (1=Never)"
label var sr_vign_`a'_t_usually "Vote (1=Usually)"
}

tab educ24, gen(sr_vign_3_t_educ)
drop sr_vign_3_t_educ2
rename sr_vign_3_t_educ1 sr_vign_3_t_educ
label var sr_vign_3_t_educ "Education (1=College degree; 0=HS diploma)"

tab charity24, gen(sr_vign_3_t_volunteer)
drop sr_vign_3_t_volunteer1
rename sr_vign_3_t_volunteer2 sr_vign_3_t_volunteer
label var sr_vign_3_t_volunteer "Volunteer in Community (1=yes; 0=no)"

tab book25, gen(sr_vign_4_t_books)
drop sr_vign_4_t_books1
rename sr_vign_4_t_books2 sr_vign_4_t_books
label var sr_vign_4_t_books "Library books (1=Return on time; 0=Return late)"

tab educ25, gen(sr_vign_4_t_educ)
drop sr_vign_4_t_educ2
rename sr_vign_4_t_educ1 sr_vign_4_t_educ
label var sr_vign_4_t_educ "Education (1=College degree; 0=HS diploma)"

forvalues i=24/25{
local a=`i'-21

tab vote`i', mis gen(sr_vign_`a'_t_party)
drop sr_vign_`a'_t_party1 
rename sr_vign_`a'_t_party2 vc_vign_`a'_t_dem
rename sr_vign_`a'_t_party3 vc_vign_`a'_t_rep
gen sr_vign_`a'_t_sameparty=0
gen sr_vign_`a'_t_opposingparty=0
replace sr_vign_`a'_t_sameparty=1 if (vc_vign_`a'_t_dem==1 & pid3==-1) | (vc_vign_`a'_t_rep==1 & pid3==1) 
replace sr_vign_`a'_t_opposingparty=1 if (vc_vign_`a'_t_dem==1 & pid3==1) | (vc_vign_`a'_t_rep==1 & pid3==-1) 
gen sr_vign_`a'_t_ind_dem=(pid3==0) & (vc_vign_`a'_t_dem==1)
gen sr_vign_`a'_t_ind_rep=(pid3==0) & (vc_vign_`a'_t_rep==1)
label var sr_vign_`a'_t_sameparty "From Preferred Party"
label var sr_vign_`a'_t_opposingparty "From Opposing Party"
label var sr_vign_`a'_t_ind_dem "Independent Presented with Democrat"
label var sr_vign_`a'_t_ind_rep "Independent Presented with Republican"
}

** SINGLE PHRASE TREATMENTS ** 
tab phrase97, gen(sr_single_1_t_phrase)
tab phrase98, gen(sr_single_2_t_phrase)
forvalues i=1/2{
rename sr_single_`i'_t_phrase1 sr_single_`i'_t_nrecycle
rename sr_single_`i'_t_phrase8 sr_single_`i'_t_recycle
rename sr_single_`i'_t_phrase2 sr_single_`i'_t_ninformed
rename sr_single_`i'_t_phrase11 sr_single_`i'_t_informed
rename sr_single_`i'_t_phrase3 sr_single_`i'_t_nvolunteer
rename sr_single_`i'_t_phrase12 sr_single_`i'_t_volunteer
rename sr_single_`i'_t_phrase4 sr_single_`i'_t_educcollege
rename sr_single_`i'_t_phrase5 sr_single_`i'_t_educhs
rename sr_single_`i'_t_phrase6 sr_single_`i'_t_taxeslate
rename sr_single_`i'_t_phrase7 sr_single_`i'_t_taxesontime
rename sr_single_`i'_t_phrase9 sr_single_`i'_t_librarylate
rename sr_single_`i'_t_phrase10 sr_single_`i'_t_libraryontime
rename sr_single_`i'_t_phrase13 sr_single_`i'_t_informedvote
rename sr_single_`i'_t_phrase14 sr_single_`i'_t_ninformedvote

label var sr_single_`i'_t_nrecycle "Doesn't Recycle"
label var sr_single_`i'_t_recycle "Recycles"
label var sr_single_`i'_t_ninformed "Doesn't Keep Informed"
label var sr_single_`i'_t_informed "Keeps Informed"
label var sr_single_`i'_t_nvolunteer "Doesn't Volunteer"
label var sr_single_`i'_t_volunteer "Volunteers"
label var sr_single_`i'_t_educcollege "College Degree"
label var sr_single_`i'_t_educhs "HS Diploma"
label var sr_single_`i'_t_taxeslate "Taxes Late"
label var sr_single_`i'_t_taxesontime "Taxes on Time"
label var sr_single_`i'_t_librarylate "Library Books Late"
label var sr_single_`i'_t_libraryontime "Library Books on Time"
label var sr_single_`i'_t_informedvote "Informed Vote"
label var sr_single_`i'_t_ninformedvote "Ill-Informed Vote"

//drop sr_single_`i'_t_nrecycle 
}

tab yal99a, gen(sr_single_3_t_vote)
label var sr_single_3_t_vote1 "Always Vote"
label var sr_single_3_t_vote2 "Usually Vote"
label var sr_single_3_t_vote3 "Never Vote"

//drop sr_single_3_t_vote3

tab yal100a, gen(sr_single_party)
label var sr_single_party1 "Democrat"
label var sr_single_party2 "Republican"
gen sr_single_4_t_sameparty=0
gen sr_single_4_t_opposingparty=0
replace sr_single_4_t_sameparty=1 if (sr_single_party1==1 & pid3==-1) | (sr_single_party2==1 & pid3==1) 
replace sr_single_4_t_opposingparty=1 if (sr_single_party1==1 & pid3==1) | (sr_single_party2==1 & pid3==-1) 
gen sr_single_4_t_ind_dem=(pid3==0) & (sr_single_party1==1)
gen sr_single_4_t_ind_rep=(pid3==0) & (sr_single_party2==1)
label var sr_single_4_t_sameparty "From Preferred Party"
label var sr_single_4_t_opposingparty "From Opposing Party"
label var sr_single_4_t_ind_dem "Independent Presented with Democrat"
label var sr_single_4_t_ind_rep "Independent Presented with Republican"

** Recode Outcome Measures to scale from -3 to 3 with higher values indicating more favorable evaluations.
foreach i in yala22* yala23* yala24* yala25* yala97* yala98* yala99* yala100* {
recode `i' (1=3) (2=2) (3=1) (4=0) (5=-1) (6=-2) (7=-3) (8=.)
}
** Generate mean indices for outcomes
egen eval_vign=rmean(yala23*)
label var eval_vign "Social evaluations scale (3 items, -3 to 3)"

egen sr_single_1_eval=rmean(yala97*)
egen sr_single_2_eval=rmean(yala98*)
egen sr_single_3_eval=rmean(yala99*)
egen sr_single_4_eval=rmean(yala100*)

** Set sample
reg eval_vign sr_single_*_eval r_black r_hispanic r_other age female educ income incomemis interest pid, r
drop if e(sample)==0

*** BALANCE CHECKS
gen bal_var_vign_2 = sr_vign_2_t_always + 2*sr_vign_2_t_usually + 10*(sr_vign_2_t_current+1)+100*sr_vign_2_t_recycle
mlogit bal_var_vign_2 r_black r_hispanic r_other age female educ income incomemis interest pid, r

*** SUMMARY STATS
outsum r_white  r_black r_hispanic r_other age female educ income incomemis interest pid using "Tables/TableA1_summarystats", bracket replace ctitle(2009 CCES)

** Current events x Voting INTERACTION 
gen vign_2alwaysXcurrent=sr_vign_2_t_always*sr_vign_2_t_current
gen vign_2usuallyXcurrent=sr_vign_2_t_usually*sr_vign_2_t_current
gen vign_2neverXcurrent=sr_vign_2_t_never*sr_vign_2_t_current
label var vign_2alwaysXcurrent "Current Events (1=Stays informed; 0=Does not stay informed) x Vote (Always)"
label var vign_2usuallyXcurrent "Current Events x Vote (Usually)"
label var vign_2neverXcurrent "Current Events x Vote (Never)"

**Indicators instead of interactions
recode sr_vign_2_t_current (1=0) (0=1), gen(ncurrent)
gen vign_2alwaysXncurrent=sr_vign_2_t_always*ncurrent
gen vign_2usuallyXncurrent=sr_vign_2_t_usually*ncurrent
gen vign_2neverXncurrent=sr_vign_2_t_never*ncurrent
label var vign_2alwaysXncurrent "Doesn't Stay Informed and Always Votes"
label var vign_2usuallyXncurrent "Doesn't Stay Informed and Usually Votes"
label var vign_2neverXncurrent "Doesn't Stay Informed and Never Votes"
label var vign_2alwaysXcurrent "Stays Informed and Always Votes"
label var vign_2usuallyXcurrent "Stays Informed and Usually Votes"
label var vign_2neverXcurrent "Stays Informed and Never Votes"

drop sr_vign_2_t_always sr_vign_2_t_usually sr_vign_2_t_never ncurrent

reg eval_vign vign_2* sr_vign_2_t* r_black r_hispanic r_other age female educ income incomemis interest pid, r
sum eval_vign 
local sd=r(sd)

foreach i in current ncurrent{
lincom vign_2alwaysX`i'-vign_2neverX`i'
local est_`i' = r(estimate)
test vign_2alwaysX`i'==vign_2neverX`i'
local p_`i' = r(p)
}
outreg using "Tables/TableA3_vign_interact", se bracket replace rdec(3) adec(3) addstat("Standard Deviation of Outcome",`sd',"Effect of Always v. Never Voting if Informed", `est_current',"Difference in coefficients (p-value)", `p_current',"Effect of Always v. Never Voting if Not Informed", `est_ncurrent',"Difference in coefficients (p-value)", `p_ncurrent')
reg eval_vign vign_2* sr_vign_2_t*, r
sum eval_vign 
local sd=r(sd)

foreach i in current ncurrent{
lincom vign_2alwaysX`i'-vign_2neverX`i'
local est_`i' = r(estimate)
test vign_2alwaysX`i'==vign_2neverX`i'
local p_`i' = r(p)
}
outreg using "Tables/TableA3_vign_interact", se bracket append rdec(3) adec(3) addstat("Standard Deviation of Outcome",`sd',"Effect of Always v. Never Voting if Informed", `est_current',"Difference in coefficients (p-value)", `p_current',"Effect of Always v. Never Voting if Not Informed", `est_ncurrent',"Difference in coefficients (p-value)", `p_ncurrent') 
reg eval_vign vign_2* sr_vign_2_t* r_black r_hispanic r_other age female educ income incomemis interest pid [aw=v200], r
sum eval_vign 
local sd=r(sd)

foreach i in current ncurrent{
lincom vign_2alwaysX`i'-vign_2neverX`i'
local est_`i' = r(estimate)
test vign_2alwaysX`i'==vign_2neverX`i'
local p_`i' = r(p)
}
outreg using "Tables/TableA3_vign_interact", se bracket append rdec(3)  adec(3) addstat("Standard Deviation of Outcome",`sd',"Effect of Always v. Never Voting if Informed", `est_current',"Difference in coefficients (p-value)", `p_current',"Effect of Always v. Never Voting if Not Informed", `est_ncurrent',"Difference in coefficients (p-value)", `p_ncurrent') ctitle("Weights")
reg eval_vign vign_2* sr_vign_2_t* [aw=v200], r
sum eval_vign 
local sd=r(sd)

foreach i in current ncurrent{
lincom vign_2alwaysX`i'-vign_2neverX`i'
local est_`i' = r(estimate)
test vign_2alwaysX`i'==vign_2neverX`i'
local p_`i' = r(p)
}
outreg using "Tables/TableA3_vign_interact", se bracket append rdec(3)  adec(3) addstat("Standard Deviation of Outcome",`sd',"Effect of Always v. Never Voting if Informed", `est_current',"Difference in coefficients (p-value)", `p_current',"Effect of Always v. Never Voting if Not Informed", `est_ncurrent',"Difference in coefficients (p-value)", `p_ncurrent') ctitle("Weights")

**** RESHAPE FOR SINGLE ITEMS
forvalues i=1/4{
rename sr_single_`i'_eval evaluation`i' 
}
reshape long evaluation, i(v100) j(item_vignette) 
label var evaluation "Social evaluations scale (3 items, -3 to 3)"
*replace treatments with zero if case is not from corresponding vignette
forvalues i=1/4{
foreach v of varlist sr_single_`i'_t*{
replace `v'=0 if item_vignette!=`i'
}
}
*collapse non-political treatments (first two vignettes)
foreach i in nrecycle recycle ninformed informed nvolunteer volunteer educcollege educhs taxeslate taxesontime librarylate libraryontime informedvote ninformedvote{
//collapse treats from exp 1 and 2 (sampling was w/o replacement)
replace sr_single_1_t_`i'=sr_single_1_t_`i'+sr_single_2_t_`i'
//remove duplicate indicators from regression
rename sr_single_2_t_`i' null_sr_single_2_t_`i'
}
***balance test
gen condition=1
local count=1
foreach i of varlist sr_single_*_t*{
replace condition =`count' if `i'==1
local count=`count'+1
}
mlogit condition r_black r_hispanic r_other age female educ income incomemis interest pid, r
//REF CATEGORY
rename sr_single_1_t_educhs ref_sr_single_1_t_educhs

***** SINGLE ITEM REGRESSION
reg evaluation sr_single_*_t* r_black r_hispanic r_other age female educ income incomemis interest pid, cluster(v100)
est store base
sum evaluation 
outreg using "Tables/TableA2_singleitemOLS", addstat("Standard Deviation of Outcome",r(sd)) se bracket replace rdec(3) adec(3)
test sr_single_1_t_informedvote== sr_single_1_t_volunteer

foreach i in sr_single_1_t_nrecycle sr_single_1_t_nvolunteer sr_single_1_t_taxeslate sr_single_1_t_librarylate sr_single_4_t_opposingparty sr_single_1_t_ninformed sr_single_3_t_vote3 { 
test sr_single_1_t_ninformedvote = `i'
}

sum age educ interest
sum income if incomemis==0
foreach i in sr_single_1_t_recycle sr_single_1_t_nrecycle sr_single_1_t_volunteer sr_single_1_t_nvolunteer sr_single_1_t_taxesontime sr_single_1_t_taxeslate sr_single_1_t_libraryontime sr_single_1_t_librarylate sr_single_1_t_educcollege sr_single_1_t_informedvote sr_single_1_t_ninformedvote sr_single_1_t_informed sr_single_1_t_ninformed sr_single_3_t_vote1 sr_single_3_t_vote2 sr_single_3_t_vote3 sr_single_1_t_ninformed sr_single_1_t_informed sr_single_1_t_informedvote sr_single_1_t_ninformedvote sr_single_4_t_sameparty sr_single_4_t_opposingparty {
est restore base
lincomest `i'+_cons+age*49.36601+educ*3.253595+interest*3.470588+income*7.68661+female
est store `i'
}
est restore base
lincomest _cons+0+age*49.36601+educ*3.253595+interest*3.470588+income*7.68661+female
est store hs_diploma

*** CREATE FIGURES 1 AND 2
coefplot (sr_single_3_t_vote3, rename((1) = "Never Votes" ) \ sr_single_3_t_vote2, rename((1) = "Usually Votes" )  \ sr_single_3_t_vote1, rename((1) = "Always Votes" ) \ sr_single_1_t_ninformedvote, rename((1) = "Votes Capriciously" )\ sr_single_1_t_informedvote, rename((1) = "Votes Based on Policy" ) msymbol(O) connect(none) msize(medium) mcolor(black) ciopts(lcolor(black) lwidth(thin)) label(Coefs)) , vertical legend(off) level(95) coeflabels(,wrap(12)) title("Figure 1: Evaluations of Individuals By Frequency and Type of Voting",  size(med)) ytitle("Estimated Rating of Individual",  size(medsmall)) note("Note: Markers indicate expected value on (-3 to +3) evaluation scale for a white, female, pure Independent" "respondent at the sample mean on age, income, education, and interest in politics." "Whiskers indicate 95% confidence intervals.",  size(small) span)   graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) ylabel(-2 -1 0 1 2) yline(0, lc(black) lw(thin) ) xscale(lw(none)) xlabel(, labsize(small)) 
graph export "Figures/figure_1.tif", as(tif) width(4000) replace
//graph export "Figures/figure_1.pdf", as(pdf) replace

coefplot (sr_single_1_t_nrecycle, rename((1) = "Doesn't Recycle")  \ sr_single_1_t_nvolunteer, rename((1) = "Doesn't Volunteer" ) \ sr_single_1_t_taxeslate, rename((1) = "Pays Taxes Late" )  \ sr_single_1_t_librarylate, rename((1) = "Returns Library Books Late" ) \ sr_single_4_t_opposingparty, rename((1) = "Out- Partisan" ) \ sr_single_3_t_vote3, rename((1) = "Never Votes" ) \ sr_single_1_t_ninformed, rename((1) = "Generally Ill-Informed" ) \ sr_single_1_t_ninformedvote, rename((1) = "Votes Capriciously" ) msymbol(O) connect(none) msize(medium) mcolor(black) ciopts(lcolor(black) lwidth(thin)) label(Coefs)) , vertical legend(off) level(95) coeflabels(,wrap(12)) title("Figure 2: Benchmarking Evaluations of Ill-Informed Voters",  size(med)) ytitle("Estimated Rating of Individual",  size(medsmall)) note("Note: Markers indicate expected value on (-3 to +3) evaluation scale for a white, female, pure Independent" "respondent at the sample mean on age, income, education, and interest in politics." "Whiskers indicate 95% confidence intervals.",  size(small) span) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) ylabel(-2 -1 0 1 2) yline(0, lc(black) lw(thin) ) xscale(lw(none)) xlabel(, labsize(small)) 
graph export "Figures/figure_2.tif", as(tif) width(4000) replace
//graph export "Figures/figure_2.pdf", as(pdf) replace

**model robustness  
//Fixed effects
xtreg evaluation sr_single_*_t*, i(v100) vce(cluster v100) fe
sum evaluation 
outreg using "Tables/TableA2_singleitemOLS", addstat("Standard Deviation of Outcome",r(sd)) se bracket append rdec(3) adec(3) ctitle ("Fixed Effects")
//no covaraites
reg evaluation sr_single_*_t*, cluster(v100) 
sum evaluation 
outreg using "Tables/TableA2_singleitemOLS", addstat("Standard Deviation of Outcome",r(sd)) se bracket append rdec(3) adec(3) ctitle ("No Covariates")
//Covariates + weights
reg evaluation sr_single_*_t* r_black r_hispanic r_other age female educ income incomemis interest pid [aw=v200], cluster(v100) 
sum evaluation 
outreg using "Tables/TableA2_singleitemOLS", addstat("Standard Deviation of Outcome",r(sd)) se bracket append rdec(3) adec(3) ctitle("Weights")
//FEs + weights
xtreg evaluation sr_single_*_t* [pw=v200], i(v100) vce(cluster v100) fe
sum evaluation 
outreg using "Tables/TableA2_singleitemOLS", addstat("Standard Deviation of Outcome",r(sd)) se bracket append rdec(3) adec(3) ctitle("Weights, FEs")
//no covariates + weights
reg evaluation sr_single_*_t* [aw=v200], cluster(v100) 
sum evaluation 
outreg using "Tables/TableA2_singleitemOLS", addstat("Standard Deviation of Outcome",r(sd)) se bracket append rdec(3) adec(3) ctitle ("No Covariates")

***COMPARISONS MENTIONED IN TEXT
xtreg evaluation sr_single_*_t* r_black r_hispanic r_other age female educ income incomemis interest pid, i(v100) vce(cluster v100) fe
lincom sr_single_3_t_vote1+_cons
lincom sr_single_3_t_vote1-sr_single_3_t_vote3

lincom sr_single_1_t_informedvote+_cons
lincom sr_single_3_t_vote1-sr_single_1_t_informedvote
foreach i of varlist sr_single_*_t*{
test sr_single_1_t_informedvote==`i'
}

lincom sr_single_1_t_ninformedvote+_cons
lincom sr_single_1_t_ninformedvote-sr_single_3_t_vote3
